pub struct ConsecVecMap<V> { /* private fields */ }Implementations
Sourceimpl<V> ConsecVecMap<V>
impl<V> ConsecVecMap<V>
Sourcepub fn new() -> ConsecVecMap<V>
pub fn new() -> ConsecVecMap<V>
Constructs a new empty ConsecVecMap
Sourcepub fn with_capacity(capacity: usize) -> ConsecVecMap<V>
pub fn with_capacity(capacity: usize) -> ConsecVecMap<V>
Constructs a new empty ConsecVecMap with a given capacity
pub fn get(&self, key: isize) -> Option<&V>
pub fn get_mut(&mut self, key: isize) -> Option<&mut V>
Sourcepub fn insert(&mut self, key: isize, value: V) -> Option<V>
pub fn insert(&mut self, key: isize, value: V) -> Option<V>
Inserts a new key-value pair into the map
Sourcepub fn remove(&mut self, key: isize) -> Option<V>
pub fn remove(&mut self, key: isize) -> Option<V>
Tries to remove the object with the associated key
Sourcepub fn contains_key(&mut self, key: isize) -> bool
pub fn contains_key(&mut self, key: isize) -> bool
Checks to see if this map contains a key