Struct consecutive_vecmap::ConsecVecMap [] [src]

pub struct ConsecVecMap<V> {
    // some fields omitted
}

Methods

impl<V> ConsecVecMap<V>
[src]

fn new() -> ConsecVecMap<V>

Constructs a new empty ConsecVecMap

fn with_capacity(capacity: usize) -> ConsecVecMap<V>

Constructs a new empty ConsecVecMap with a given capacity

fn is_empty(&self) -> bool

Checks to see if the map is empty

fn len(&self) -> usize

Returns the number of items that are inside the map

fn get(&self, key: isize) -> Option<&V>

fn get_mut(&mut self, key: isize) -> Option<&mut V>

fn insert(&mut self, key: isize, value: V) -> Option<V>

Inserts a new key-value pair into the map

fn remove(&mut self, key: isize) -> Option<V>

Tries to remove the object with the associated key

fn contains_key(&mut self, key: isize) -> bool

Checks to see if this map contains a key

fn iter(&self) -> Iter<V>

Returns an iterator over (isize, &V)

fn iter_mut(&mut self) -> IterMut<V>

Returns an iterator over (isize, &mut V)